DataMatrix

Struct DataMatrix 

pub struct DataMatrix;
Data Matrix ECC 200 barcode encoder.

Encodes text input into a square Data Matrix symbol. The smallest symbol that fits the data is automatically selected (10×10 to 48×48).

Example

use barcodes::common::traits::BarcodeEncoder;
use barcodes::common::types::Encoded;
use barcodes::twod::datamatrix::DataMatrix;

let mut buf = [false; 48 * 48];
let Encoded::Matrix { width, height } = DataMatrix::encode_into("Hello DM", &mut buf).unwrap()
else { unreachable!() };
assert_eq!(width, height);